pub struct TransactionProofRpc;Expand description
RPC type for fetching a light client execution proof for a transaction.
Uses the light_client_proof RPC method to retrieve the proof needed to verify
a transaction execution against a light client block.